*     ***********************************************************************
*       File-Name:      jwb figure 2 marginsplot exper with 				*
*							histo innov overlay.do							*
*       Date:           1/9/2017                                       		*
*       Author:         Rick Vanden Bergh                                   *
*       Purpose:        Do-file to produce a marginal effect plot 			*
*                       with an embedded frequency distribution 			*
*       Data Output:    none                 								*
*       Input File:     jwb_exp_moderating.dta                    			*
*       Output File:    "graph".gph											*
*		Stata Version:	13.1												*
*     ***********************************************************************


*     ****************************************************************  *
*	I modified code created by Matt Golder								*
*	If you use this code or a modified version please cite 				*
*																		*
*	Kingsley, A.K., Noordewier, T.G., Vanden Bergh, R.G., 2017			*
*		Overstating and understating interaction results in 			*
*		international business research. 								*
*		Journal of World Business 52(2), 286-295.						*
*																		*
*	Also please cite:													*
*	Matt Golder's research referenced in our paper and 					*
*		found at http://mattgolder.com/interactions 					*
*     ****************************************************************  *

clear all

set more off

use "F:\jwb_exp_moderating.dta", clear

*     ****************************************************************  *
*		generate the dependent variable FDIgrowth						*
*     ****************************************************************  *

set obs 2000
* to create Figure 1 presented in the paper set seed 38
* to create Figure 2 presented in the paper set seed 28255
set seed 28255
generate error = rnormal(0,3)
quietly generate FDIgrowth = 1 + 0.15*Experience + .005*Innovation + .0025*Experience*Innovation + error

*     ****************************************************************  *
*		regress DV on Experience, Innovation and Interaction			*
*     ****************************************************************  *

reg FDIgrowth Experience Innovation c.Innovation#c.Experience

*     ****************************************************************  *
*		capture the relevant estimates from the regression				*
*		to calculate the marginal effect of Experience on FDI Growth	*
*		over the range of values of Innovation in our data				*
*     ****************************************************************  *

matrix beta_coeff=e(b)
matrix Var_cov=e(V)

scalar beta1=beta_coeff[1,1]
scalar beta3=beta_coeff[1,3]

scalar varbeta1=Var_cov[1,1]
scalar varbeta3=Var_cov[3,3]

scalar covb1b3=Var_cov[1,3]

scalar list beta1 beta3 varbeta1 varbeta3 covb1b3

*     ****************************************************************  *
*       To calculate marginal effects for the plot, need to generate 	*
*		relevant values of Innovation to calculate						*
*       Innovation distributed between 15.6 and 65.3.  Increments of .03    *
*		_n in Stata represents the observation number 					*
*		Thus I create 1657 observations of Innovation 					*
*     ****************************************************************  *

generate Innovation_Variable =((_n+519)/33.333333)

replace  Innovation_Variable=. if _n>1657

gen marginal_effect_experience=beta1+beta3*Innovation_Variable if _n<1657

gen stderror_me_experience=sqrt(varbeta1+varbeta3*(Innovation_Variable^2)+2*covb1b3*Innovation_Variable) if _n<1657

gen ninefiveband=2*stderror_me_experience

gen upper_me_experience=marginal_effect_experience+ninefiveband

gen lower_me_experience=marginal_effect_experience-ninefiveband


*     ****************************************************************  *;
*       Construct variable to produce y=0 line.                         *;
*     ****************************************************************  *;

gen zeroyline=0

*     ****************************************************************  *;
*     ****************************************************************  *;
*       Produce marginal effect plot for X.                             *;
*		To overlay histogram of Mod Variable good to run			 	*;
*		a hist command with options "percent" and "width" to 			*;
*		determine yaxis 2 label values given "percent" and "width"		*;
*     ****************************************************************  *;
*     ****************************************************************  *;

graph twoway  hist Innovation, width(2) start(15) freq color(gs14) yaxis(2) //////
	    ||   line marginal_effect_experience   Innovation_Variable, clpattern(solid) clwidth(medium) clcolor(black) yaxis(1) /// 
        ||   line upper_me_experience  Innovation_Variable, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||   line lower_me_experience  Innovation_Variable, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||   line zeroyline  Innovation_Variable,  clwidth(thin) clcolor(black) clpattern(solid) ///
	    ||   , ///
             xlabel(15(3)66, nogrid labsize(2)) ///
		     ylabel(-0.12 0 0.12 0.24 0.36 0.5 0.62 0.74, axis(1) nogrid labsize(2)) ///
		     ylabel(0 4 8 12 16 20, axis(2) nogrid labsize(2)) ///
	         yscale(noline alt) ///
		     yscale(noline alt axis(2))	///
             xscale(noline) ///
             legend(off) ///
             xtitle("Innovation" , size(2.5)  ) ///
             ytitle("Observation Frequency" , axis(2) size(2.5)) ///
             ytitle("Marginal Effect of Experience on FDI Growth" , axis(1) size(2.5)) ///
             xsca(titlegap(2)) ///
             ysca(titlegap(2)) ///
             ysca(titlegap(2) axis(2)) ///
			 title("Marginal Effect Experience with 95% Confidence Bands") ///
			 subtitle("Frequency Distribution of Innovation -- right hand scale")
graph save Graph "F:\ME Exp Innov and histo graph seed 28255 vfinal2.gph", replace
			 
exit
